Learn R Programming

fugeR (version 0.1.2)

fugeR-package: FUzzy GEnetic, a machine learning algorithm to construct prediction model based on fuzzy logic.

Description

This is an evolutionary algorithm for fuzzy systems, a genetic algorithm is used to construct a fuzzy system able to fit the given training data. This fuzzy system can then be used as a prediction model, it's composed of fuzzy logic rules that provide a good lingustic representation.

Arguments

Details

Package:
fugeR
Type:
Package
Version:
0.1
Date:
2012-07-11
License:
GPL (>= 2)
LazyLoad:
yes

This package allow you to use a genetic algorithm in order to find a fuzzy system that can be used as a prediction model.

fugeR.run find a fuzzy system. fugeR.predict make the prediction for the given input data.

References

http://library.epfl.ch/en/theses/?nr=2634

See Also

fugeR.run