fugeR.sfRun(data, labels, maxRules=4, maxVarPerRule=3, labelsMf=2, population=200, elitism=NA, mutation=0.01, generation=100, sensiW=1, speciW=1, accuW=0, threshold=0.5, rmseW=0.2, verbose=FALSE, path, rep=300, parallel=FALSE, cpus=1)data (only numeric values are supported).rep containing the performance of each fuzzy system on
training and validation set.fugeR.run a number of times
given as argument. This function use snowfall package in order to take benefit
of mutli-core computers.fugeR.sfRun sould be used when you want to repeat an experience many times.
This is usefull when you are searching the good parameters (maxRules, macVarPerRule) for a problem.
fugeR.sfRun will launch fugeR.run and test the obtained system. It automatically resamples the data
using bootstrapping method.
For example if the argument rep has the value 1000 and the number of sample in data is 100.
FugeR.sfRun resample the data with replacement with the size of the resample equal to 100
(the size of the original data set) this constitute the training set, the samples that were not picked are taken
to create the validation set. FugeR.run is then called with the training set and the obtained fuzzy systems
is tested on the validation set. If rep value was 1000, this operation is repeated 1000 times.
FugeR.sfRun saves every systems in the directory specified by path and return a resume of the performance
obtained by each system on their training and validation set.
fugeR.run fugeR.predictfugeR.summary
fugeR.save fugeR.load##
## Not run:
# expResume <- fugeR.sfRun (
# In,
# Out,
# generation=100,
# population=200,
# elitism=40,
# verbose=TRUE,
# threshold=0.5,
# sensiW=1.0,
# speciW=1.0,
# accuW=0.0,
# rmseW=1.0,
# maxRules=10,
# maxVarPerRule=2,
# labelsMf=2,
# path=\'./exp\',
# rep=100,
# parallel=TRUE,
# cpus=2
# )
# ## End(Not run)Run the code above in your browser using DataLab