| Package: |
| fugeR |
| Type: |
| Package |
| Version: |
| 0.1 |
| Date: |
| 2012-07-11 |
| License: |
| GPL (>= 2) |
| LazyLoad: |
| yes |
This package allow you to use a genetic algorithm in order to find a fuzzy system that can be used as a prediction model.
fugeR.run find a fuzzy system. fugeR.predict
make the prediction for the given input data.
fugeR.run